#!/bin/bash
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.

# ===| BASH Stub |=============================================================

# The beginning of this script is both valid shell and valid python,
# such that the script starts with the shell and is reexecuted with
# the right python.
'''echo' $0: Starting up...
if [ -f "/opt/rh/python27/root/usr/bin/python2.7" ];then
    BINOC_PYTHON_ARGS=$@
    exec scl enable python27 "python $0 $BINOC_PYTHON_ARGS"
elif BINOC_PYTHON_PATH="$(which python2.7 2>/dev/null)"; then
    exec $BINOC_PYTHON_PATH $0 "$@"
else
    echo "$0 error: Python 2.7 was not found on this system"
    exit 1
fi
'''

# =============================================================================

# ===| Imports |===============================================================

from __future__ import print_function
from collections import OrderedDict
import hashlib
import os
import sys
import json
import time

# =============================================================================

# ===| function: Generate Checksum |===========================================

def funcChecksum(filename, block_size=65536):
    sha256 = hashlib.sha256()
    with open(filename, 'rb') as f:
        for block in iter(lambda: f.read(block_size), b''):
            sha256.update(block)
    return sha256.hexdigest()

# =============================================================================

# ===| function: Read JSON File |==============================================

def funcReadJson(filename):
    with open(filename) as json_data:
        _jsonData = json.load(json_data)
    return(_jsonData)

# =============================================================================

# ===| Function: Generate JSON |===============================================

def funcGenJson(_value):
    return json.dumps(_value, sort_keys=True, ensure_ascii=False, indent=2)

# =============================================================================

# ===| Main |=================================================================

pathCurrent = os.getcwd()

if os.path.isfile(pathCurrent + '/release.manifest'):
  time.sleep(2)
  os.remove(pathCurrent + '/release.manifest')

listDirs = os.listdir(pathCurrent)
listFiles = []
dictFinalFiles = {
  "linux64-gtk2": {},
  "linux64-gtk3": {},
  "win64": {},
  "win32": {}
}

for _dir in listDirs:
  listFiles = os.listdir(_dir)
  for _file in listFiles:
    if _file.endswith(".json"):
      _jsonMozilla = funcReadJson(pathCurrent + "/" + _dir + "/" + _file)
      dictFinalFiles[_dir]["meta"] = {
        "version": _jsonMozilla['moz_app_version'],
        "displayVersion": _jsonMozilla['moz_app_version'][5:],
        "buildid": _jsonMozilla['buildid'],
      }

  for _file in listFiles:
    _pathFile = pathCurrent + "/" + _dir + "/" + _file
    if _file.endswith(".tar.bz2") or _file.endswith(".zip"):
      dictFinalFiles[_dir]['archive'] = {
        "file": _file,
        "size": os.path.getsize(_pathFile),
        "sha256": funcChecksum(_pathFile),
      }
    elif _file.endswith(".exe"):
      dictFinalFiles[_dir]["installer"] = {
        "file": _file,
        "size": os.path.getsize(_pathFile),
        "sha256": funcChecksum(_pathFile),
      }
    elif _file.endswith(".mar"):
      dictFinalFiles[_dir]["update"] = {
        "file": _file,
        "size": os.path.getsize(_pathFile),
        "sha256": funcChecksum(_pathFile),
      }

dictFinalFiles = funcGenJson(dictFinalFiles)

fileManifest = open(pathCurrent + '/release.manifest', 'w', 0)
fileManifest.write(dictFinalFiles)
fileManifest.close()
print(dictFinalFiles)

# =============================================================================